@@ -6,6 +6,7 @@ import pandas as pd
 from region_estimators.region_estimator import RegionEstimator
 from region_estimators.concentric_regions_estimator import ConcentricRegionsEstimator
 from region_estimators.distance_simple_estimator import DistanceSimpleEstimator
+from region_estimators.estimation_data import EstimationData
 
 class TestRegionEstimator(unittest.TestCase):
   """
@@ -37,7 +38,8 @@ class TestRegionEstimator(unittest.TestCase):
     Test that a RegionEstimator object can be initialized with good data.
     Also check that various other initializations happen within the object.
     """
-    estimator = RegionEstimator(self.sites, self.regions, self.actuals, verbose=0)
+    estimation_data = EstimationData(self.sites, self.regions, self.actuals)
+    estimator = RegionEstimator(estimation_data, verbose=0)
 
     self.assertIsNotNone(estimator)
     self.assertIsNotNone(estimator.regions['sites'])
@@ -52,11 +54,12 @@ class TestRegionEstimator(unittest.TestCase):
     Test that a ConcentricRegionsEstimator and DistanceSimpleEstimator objects can
     be initialized with bad verbose.
     """
+    estimation_data = EstimationData(self.sites, self.regions, self.actuals)
     with self.assertRaises(AssertionError):
-      ConcentricRegionsEstimator(self.sites, self.regions, self.actuals, 'bad')
+      ConcentricRegionsEstimator(estimation_data, 'bad')
 
     with self.assertRaises(AssertionError):
-      DistanceSimpleEstimator(self.sites, self.regions, self.actuals, 2.14)
+      DistanceSimpleEstimator(estimation_data, 2.14)
 
 
   def test_load_actuals_with_bad_data(self):
@@ -74,7 +77,8 @@ class TestRegionEstimator(unittest.TestCase):
       with self.subTest(file=file):
         with self.assertRaises(AssertionError):
           bad_actuals = pd.read_csv(path.join(self.load_data, file))
-          ConcentricRegionsEstimator(self.sites, self.regions, bad_actuals)
+          estimation_data = EstimationData(self.sites, self.regions, bad_actuals)
+          estimator = ConcentricRegionsEstimator(estimation_data)
 
   def test_load_regions_with_bad_data(self):
     """
@@ -88,7 +92,8 @@ class TestRegionEstimator(unittest.TestCase):
       with self.subTest(file=file):
         with self.assertRaises(AssertionError):
           bad_regions = pd.read_csv(path.join(self.load_data, file))
-          ConcentricRegionsEstimator(self.sites, bad_regions, self.actuals)
+          estimation_data = EstimationData(self.sites, bad_regions, self.actuals)
+          estimator = ConcentricRegionsEstimator(estimation_data)
 
   def test_load_sites_with_bad_data(self):
     """
@@ -105,40 +110,43 @@ class TestRegionEstimator(unittest.TestCase):
       with self.subTest(file=file):
         with self.assertRaises(AssertionError):
           bad_sites = pd.read_csv(path.join(self.load_data, file))
-          DistanceSimpleEstimator(bad_sites, self.regions, self.actuals)
+          estimation_data = EstimationData(bad_sites, self.regions, self.actuals)
+          DistanceSimpleEstimator(estimation_data)
 
   def test_get_region_sites(self):
     """
     Check that get_region_sites works with good and bad inputs
     """
-    estimator = RegionEstimator(self.sites, self.regions, self.actuals)
+    estimation_data = EstimationData(self.sites, self.regions, self.actuals)
+    estimator = RegionEstimator(estimation_data)
 
     with self.assertRaises(AssertionError):
         # Test that region_id not in regions raises assertion error
-        estimator.get_region_sites('WC')
+        estimator.estimation_data.get_region_sites('WC')
 
     # Test a region_id known to be present in regions and has sites
-    region_sites = estimator.get_region_sites('DG')
+    region_sites = estimator.estimation_data.get_region_sites('DG')
     self.assertEqual(region_sites, ['1023 [POLLEN]', '1023 [WEATHER]'])
 
     # Test a region_id known to be present in regions and does not contain sites
-    region_no_sites = estimator.get_region_sites('AB')
+    region_no_sites = estimator.estimation_data.get_region_sites('AB')
     self.assertEqual(region_no_sites, [])
 
   def test_site_region(self):
     """
     Check that get_region_id works with good and bad inputs
     """
-    estimator = RegionEstimator(self.sites, self.regions, self.actuals)
+    estimation_data = EstimationData(self.sites, self.regions, self.actuals)
+    estimator = RegionEstimator(estimation_data)
 
     with self.assertRaises(AssertionError):
         # Test that an invalid site_id raises assertion error
-        estimator.get_region_id(750)
+        estimator.estimation_data.get_region_id(750)
         # Test that site_id not in sites raises assertion error
-        estimator.get_region_id('1023333 [POLLLLLLEN]')
+        estimator.estimation_data.get_region_id('1023333 [POLLLLLLEN]')
 
     # Test a site_id known to be present in sites
-    region_id = estimator.get_region_id('1023 [POLLEN]')
+    region_id = estimator.estimation_data.get_region_id('1023 [POLLEN]')
     self.assertEqual(region_id, 'DG')
 
   def test_site_and_region_index_names(self):
@@ -154,7 +162,8 @@ class TestRegionEstimator(unittest.TestCase):
         # Test that loading incorrect regions index name raises assertion
         regions = pd.DataFrame(self.regions)
         regions.index = regions.index.rename('postcode')
-        estimator = ConcentricRegionsEstimator(self.sites, regions, self.actuals)
+        estimation_data = EstimationData(self.sites, regions, self.actuals)
+        estimator = ConcentricRegionsEstimator(estimation_data)
 
   def test_max_processors(self):
     """
@@ -163,5 +172,6 @@ class TestRegionEstimator(unittest.TestCase):
 
     with self.assertRaises(AssertionError):
         # Test that loading incorrect max_processors raises assertion
-        estimator = ConcentricRegionsEstimator(self.sites, self.regions, self.actuals, verbose=0, max_processors=0)
-        estimator = ConcentricRegionsEstimator(self.sites, self.regions, self.actuals, verbose=0, max_processors=500)
\ No newline at end of file
+        estimation_data = EstimationData(self.sites, self.regions, self.actuals)
+        estimator = ConcentricRegionsEstimator(estimation_data, verbose=0, max_processors=0)
+        estimator = ConcentricRegionsEstimator(estimation_data, verbose=0, max_processors=500)
\ No newline at end of file
